=============
API Reference
=============

.. currentmodule:: environ


The ``__init__`` module
=======================

.. automodule:: environ
    :members:
    :special-members:
    :no-undoc-members:


The ``compat`` module
======================

.. automodule:: environ.compat
    :members:
    :no-undoc-members:


The ``environ`` module
======================

.. autoclass:: environ.Env
    :members:
    :no-undoc-members:

.. autoclass:: environ.FileAwareEnv
    :members:
    :no-undoc-members:

.. autoclass:: environ.Path
    :members:
    :no-undoc-members:


The ``fileaware_mapping`` module
================================

.. autoclass:: environ.fileaware_mapping.FileAwareMapping
    :members:
    :no-undoc-members:
